@@ -31,12 +31,11 @@
 #define __OSSPRC_CONST_H__
 
 /* Generic text, should include newline termination */
-#define RC_NON_TEXT "No options exist.\n"
-#define RC_LST_TEXT "Please enter just one rcfile name and at least one section label.\n"
-#define RC_EEP_TEXT "The exec, eval, and print options may not be combined.\n"
-#define RC_SLO_TEXT "The silent option may not be combined with output options.\n"
-#define RC_SUM_TEXT "Option argument summary.\n"
-#define RC_RUT_TEXT "Failed to set the user id. Please become the root user and try again.\n"
+#define RC_LST_TEXT "OSSP rc:Failure, please enter just one rcfile name and at least one section label.\n"
+#define RC_EEP_TEXT "OSSP rc:Failure, the exec, eval, and print options may not be combined.\n"
+#define RC_SLO_TEXT "OSSP rc:Failure, the silent option may not be combined with output options.\n"
+#define RC_RUT_TEXT "OSSP rc:Failure, failed to set the user id. Please become the root user and try again.\n"
+#define RC_SUM_TEXT "OSSP rc:Info, option argument summary.\n"
 
 /* Generic text, should not include newline termination */
 #define RC_VST_TEXT "# Start of run command script operations."
@@ -83,18 +82,18 @@
 
 /* Error messages with newline termination */
 #define RC_ERRTXT_ALL  "Error condition in %s:%s():%d.\n"
-#define RC_ERRTXT_USE  "OSSP rc:API usage is wrong.\n"
-#define RC_ERRTXT_MEM  "OSSP rc:Memory allocation failure.\n"
-#define RC_ERRTXT_SYS  "OSSP rc:Underlying system failure.\n"
-#define RC_ERRTXT_IO   "OSSP rc:Input output failure.\n"
-#define RC_ERRTXT_INT  "OSSP rc:Internal failure.\n"
-#define RC_ERRTXT_FNC  "OSSP rc:Function file %s could not be opened.\n"
-#define RC_ERRTXT_LOC  "OSSP rc:Location dir %s could not be opened.\n"
-#define RC_ERRTXT_TMP  "OSSP rc:Temporary dir %s could not be opened.\n"
-#define RC_ERRTXT_RCF  "OSSP rc:One or more rc files could not be opened.\n"
-#define RC_ERRTXT_CFG  "OSSP rc:Configuration failure.\n"
-#define RC_ERRTXT_ROOT "OSSP rc:You must be root to run these commands.\n"
-#define RC_ERRTXT_GEN  "OSSP rc:Generic failure condition of class '%s',.\n"
+#define RC_ERRTXT_USE  "OSSP rc:Failure, API usage is wrong.\n"
+#define RC_ERRTXT_MEM  "OSSP rc:Failure, memory allocation.\n"
+#define RC_ERRTXT_SYS  "OSSP rc:Failure, underlying system.\n"
+#define RC_ERRTXT_IO   "OSSP rc:Failure, input output.\n"
+#define RC_ERRTXT_INT  "OSSP rc:Failure, internal problem.\n"
+#define RC_ERRTXT_FNC  "OSSP rc:Failure, function file %s could not be opened.\n"
+#define RC_ERRTXT_LOC  "OSSP rc:Failure, location dir %s could not be opened.\n"
+#define RC_ERRTXT_TMP  "OSSP rc:Failure, temporary dir %s could not be opened.\n"
+#define RC_ERRTXT_RCF  "OSSP rc:Failure, one or more rc files could not be opened.\n"
+#define RC_ERRTXT_CFG  "OSSP rc:Failure, configuration problem.\n"
+#define RC_ERRTXT_ROOT "OSSP rc:Failure, you must be root to run these commands.\n"
+#define RC_ERRTXT_GEN  "OSSP rc:Failure, generic problem of class '%s',.\n"
 
 /* Option friendly names, should not include newline termination */
 #define RC_USE_NAME "usage"
@@ -158,7 +157,7 @@
 #define RC_DEF_ON     "1"                       /* Digital switch */
 #define RC_DEF_OFF    "0"                       /* Digital switch */
 #define RC_DEF_TMP    "/tmp"                    /* Temporary directory name */
-#define RC_DEF_DEF    "(?:^|\\n)%(\\w+)[ \t]*(.*?)\\n(.*?)(?:\\n%|$)" /* Section definition */
+#define RC_DEF_DEF    "^%(\\w+)[ \t]*(.*?)\\n(.*?)^$" /* Section definition */
 #define RC_DEF_NCF    "config"                  /* Config section name */
 #define RC_DEF_CMN    "common"                  /* Common section name */
 #define RC_DEF_UIG    "-u"                      /* Section user string */
