@@ -149,7 +149,7 @@ rc_return_t rcfileParse(rc_file_t *pRcf)
         int nSubstrings    = 0;
         int *pnVec         = NULL;
         const char *kszErr = NULL;
-        const int kiRegopt = PCRE_DOTALL | PCRE_DOLLAR_ENDONLY;
+        const int kiRegopt = PCRE_DOTALL | PCRE_MULTILINE;
         /*const int kiRegopt = PCRE_DOTALL | PCRE_MULTILINE | PCRE_UNGREEDY;*/
 
         pcre *pRegex       = NULL;  /* Perl Compatible Regular Expression */
